@@ -33,9 +33,10 @@
 #  define KIDENTITYMANAGEMENT_DEPRECATED_NO_EXPORT KIDENTITYMANAGEMENT_NO_EXPORT KIDENTITYMANAGEMENT_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KIDENTITYMANAGEMENT_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KIDENTITYMANAGEMENT_NO_DEPRECATED
+#    define KIDENTITYMANAGEMENT_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
